@@ -5,7 +5,7 @@
  *     Copyright (C) 2001-2003 by Stefan Kamphausen
  *     Author: Stefan Kamphausen <mail@skamphausen.de>
  *
- *     Time-stamp: <31-Mar-2004 18:28:03 ska>
+ *     Time-stamp: <31-Dec-2004 00:24:13 ska>
  * 
  *     This program is free software; you can redistribute it and/or modify
  *     it under the terms of the GNU General Public License as published by
@@ -57,7 +57,8 @@ using namespace std;
 # include <signal.h>
 # include <string.h>
 
-# if defined(USE_NCURSES) && !defined(RENAMED_NCURSES)
+//# if defined(USE_NCURSES) && !defined(RENAMED_NCURSES)
+# if defined(HAVE_NCURSES_H)
 # include <ncurses.h>
 # else
 # include <curses.h>
@@ -267,9 +268,11 @@ void toggle_mode(void) {
                 mode = BROWSE;
                 list_from_dir(".");
             }
-        } else {         // the "normal" case; disable Needle here!
+        } else {         // the "normal" case;
+            // disable Needle and reload the list!
             NeedleGiven = false;
             Needle = NULL;
+            list_from_file();
             yoffset = 0;
             shorties_offset = 0;
             CurrPosition = 0;
@@ -723,6 +726,10 @@ void list_to_file(void) {
     if(opt_user.size() > 0) {
         return;
     }
+    string backup_file = mylistfile + "~";
+    if(rename(mylistfile.c_str(),backup_file.c_str()) == -1) {
+        fprintf(stderr,"warning: could not create backupfile\n");
+    }
     ofstream listfile(mylistfile.c_str());
     if (!listfile) {
         fatal_exit("couldn't write listfile");
